@@ -849,7 +849,7 @@ class Hand(object):
         return '.'.join(hand_list)
 
     @staticmethod
-    def sort_card_list(cards: List[Card], suit_order: str='', high_card_left: bool=True) -> list[Card]:
+    def sort_card_list(cards: List[Card], suit_order: str='', high_card_left: bool=True) -> List[Card]:
         """Return a list of cards sorted by suit and rank."""
         if not suit_order:
             suit_order = DISPLAY_SUIT_ORDER
