@@ -107,13 +107,13 @@ board = Board()
 
 def test_board_vulnerable_setter_none_default():
     """Ensure that a board vulnerable setter works correctly: no parameter"""
-    assert board.vulnerable is None
+    assert board.vulnerable == ''
 
 
 def test_board_vulnerable_setter_none():
     """Ensure that a board vulnerable setter works correctly: None (valid)."""
-    board.vulnerable = 'None'
-    assert board.vulnerable == 'None'
+    board.vulnerable = ''
+    assert board.vulnerable == ''
 
 
 def test_board_vulnerable_setter_all():
@@ -147,7 +147,7 @@ board = Board()
 
 def test_board_declarer_setter_no_parameter():
     """Ensure that a board declarer setter works correctly: no parameter."""
-    assert board.declarer is None
+    assert board.declarer == ''
     assert board.declarer_index == -1
 
 
@@ -206,14 +206,14 @@ def test_board_declarer_index_setter_invalid_parameter():
 def test_board_declarer_index_setter_question():
     """Ensure that a board declarer index setter works correctly: question point."""
     board.declarer_index = 4
-    assert board.declarer is None
+    assert board.declarer == ''
     assert board.declarer_index == -1
 
 
 def test_board_dealer_setter_no_parameter():
     """Ensure that a board dealer setter works correctly: no parameter."""
     board = Board()
-    assert board.dealer is None
+    assert board.dealer == ''
     assert board.dealer_index == -1
 
 
@@ -233,7 +233,7 @@ def test_board_dealer_setter_invalid_parameter_string():
     board = Board()
     with pytest.raises(ValueError) as exc_info:
         board.dealer = 'Q'
-    assert board.dealer is None
+    assert board.dealer == ''
     assert board.dealer_index == -1
 
 
@@ -242,14 +242,14 @@ def test_board_dealer_setter_invalid_parameter_integer():
     board = Board()
     with pytest.raises(ValueError):
         board.dealer_index = 4
-    assert board.dealer is None
+    assert board.dealer == ''
     assert board.dealer_index == -1
 
 
 def test_board_dealer_index_setter_no_parameter():
     """Ensure that a board dealer index setter works correctly: no parameter."""
     board = Board()
-    assert board.dealer is None
+    assert board.dealer == ''
     assert board.dealer_index == -1
 
 
@@ -266,7 +266,7 @@ def test_board_dealer_index_setter_invalid_parameter_string():
     """Ensure that a board dealer index setter works correctly: invalid parameter."""
     with pytest.raises(ValueError):
         board.dealer_index = 'Q'
-    assert board.dealer is None
+    assert board.dealer == ''
     assert board.dealer_index == -1
 
 
