@@ -15,7 +15,7 @@ def test_trick_repr():
 def test_trick_str():
     """Ensure the str is correct."""
     trick = Trick([Card('AH'), Card('2H'), Card('3H'), Card('4H')])
-    assert str(trick) == ('Trick: Leader: None, winner: None, , cards: AH, 2H, 3H, 4H')
+    assert str(trick) == ('Trick: Leader: '', winner: '', , cards: AH, 2H, 3H, 4H')
 
 
 def test_trick_cards_setter():
